@@ -3,8 +3,8 @@ use strict;
 use warnings;
 package Email::MIME;
 # ABSTRACT: easy MIME message handling
-$Email::MIME::VERSION = '1.941'; # TRIAL
-use Email::Simple 2.206; # header_raw
+$Email::MIME::VERSION = '1.942'; # TRIAL
+use Email::Simple 2.212; # nth header value
 use parent qw(Email::Simple);
 
 use Carp ();
@@ -141,7 +141,11 @@ sub new {
 #pod
 #pod This method creates a new MIME part. The C<header_str> parameter is a list of
 #pod headers pairs to include in the message. The value for each pair is expected to
-#pod be a text string that will be MIME-encoded as needed.  A similar C<header>
+#pod be a text string that will be MIME-encoded as needed.  Alternatively it can be
+#pod an object with C<as_mime_string> method which implements conversion of that
+#pod object to MIME-encoded string.  That object method is called with two input
+#pod parameters: charset and length of header name and should return MIME-encoded
+#pod representation of the object.  A similar C<header>
 #pod parameter can be provided in addition to or instead of C<header_str>.  Its
 #pod values will be used verbatim.
 #pod
@@ -448,6 +452,11 @@ sub header_str_pairs {
   $self->header_obj->header_str_pairs(@_);
 }
 
+sub header_as_obj {
+  my $self = shift;
+  $self->header_obj->header_as_obj(@_);
+}
+
 #pod =method content_type_set
 #pod
 #pod   $email->content_type_set( 'text/html' );
@@ -866,7 +875,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.941
+version 1.942
 
 =head1 SYNOPSIS
 
@@ -975,7 +984,11 @@ very long. Added to that, you have:
 
 This method creates a new MIME part. The C<header_str> parameter is a list of
 headers pairs to include in the message. The value for each pair is expected to
-be a text string that will be MIME-encoded as needed.  A similar C<header>
+be a text string that will be MIME-encoded as needed.  Alternatively it can be
+an object with C<as_mime_string> method which implements conversion of that
+object to MIME-encoded string.  That object method is called with two input
+parameters: charset and length of header name and should return MIME-encoded
+representation of the object.  A similar C<header>
 parameter can be provided in addition to or instead of C<header_str>.  Its
 values will be used verbatim.
 
@@ -1124,6 +1137,9 @@ This behaves like C<header_raw_set>, but expects Unicode (character) strings as
 the values to set, rather than pre-encoded byte strings.  It will encode them
 as MIME encoded-words if they contain any control or 8-bit characters.
 
+Alternatively, values can be objects with C<as_mime_string> method.  Same as in
+method C<create>.
+
 =head2 header_str_pairs
 
   my @pairs = $email->header_str_pairs;
@@ -1132,6 +1148,23 @@ This method behaves like C<header_raw_pairs>, returning a list of field
 name/value pairs, but the values have been decoded to character strings, when
 possible.
 
+=head2 header_as_obj
+
+  my $first_obj = $email->header_as_obj($field);
+  my $nth_obj   = $email->header_as_obj($field, $index);
+  my @all_objs  = $email->header_as_obj($field);
+
+  my $nth_obj_of_class  = $email->header_as_obj($field, $index, $class);
+  my @all_objs_of_class = $email->header_as_obj($field, undef, $class);
+
+This method returns an object representation of the header value.  It instances
+new object via method C<from_mime_string> of specified class.  Input argument
+for that class method is list of the raw MIME-encoded values.  If class argument
+is not specified then class name is taken from the hash
+C<%Email::MIME::Header::header_to_class_map> via key field.  Use class method
+C<< Email::MIME::Header->set_class_for_header($class, $field) >> for adding new
+mapping.
+
 =head2 parts
 
 This returns a list of C<Email::MIME> objects reflecting the parts of the
@@ -1332,6 +1365,9 @@ __END__
 #pod the values to set, rather than pre-encoded byte strings.  It will encode them
 #pod as MIME encoded-words if they contain any control or 8-bit characters.
 #pod
+#pod Alternatively, values can be objects with C<as_mime_string> method.  Same as in
+#pod method C<create>.
+#pod
 #pod =method header_str_pairs
 #pod
 #pod   my @pairs = $email->header_str_pairs;
@@ -1340,6 +1376,23 @@ __END__
 #pod name/value pairs, but the values have been decoded to character strings, when
 #pod possible.
 #pod
+#pod =method header_as_obj
+#pod
+#pod   my $first_obj = $email->header_as_obj($field);
+#pod   my $nth_obj   = $email->header_as_obj($field, $index);
+#pod   my @all_objs  = $email->header_as_obj($field);
+#pod
+#pod   my $nth_obj_of_class  = $email->header_as_obj($field, $index, $class);
+#pod   my @all_objs_of_class = $email->header_as_obj($field, undef, $class);
+#pod
+#pod This method returns an object representation of the header value.  It instances
+#pod new object via method C<from_mime_string> of specified class.  Input argument
+#pod for that class method is list of the raw MIME-encoded values.  If class argument
+#pod is not specified then class name is taken from the hash
+#pod C<%Email::MIME::Header::header_to_class_map> via key field.  Use class method
+#pod C<< Email::MIME::Header->set_class_for_header($class, $field) >> for adding new
+#pod mapping.
+#pod
 #pod =method parts
 #pod
 #pod This returns a list of C<Email::MIME> objects reflecting the parts of the
